==> org-lsst-ccs-buses-definition-1.0.7-sources.jar: org/lsst/ccs/bus/Command.java <==
package org.lsst.ccs.bus;

import org.apache.log4j.Logger;
import org.lsst.ccs.bus.CommandBusMessage;
import org.lsst.ccs.bus.CommandExecutor;

/**
 * A command sent on the CCS bus
 * 
 * Will be executed by the destination subsystem.
 * 
 * 
 * @author Eric Aubourg
 * 
 */

public abstract class Command extends BusMessage implements CommandBusMessage {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1350212411027899551L;
	protected static Logger log = Logger.getLogger("lsst.ccs.bus.Command");

	public abstract Object execute(CommandExecutor s);

	@Override
	public String getMessageType() {
		return "lsst.command";
	}

	/* targeting */

	protected String destination = "*";

	/**
	 * The command destination : subsystem name or "*"
	 * 
	 * @return command destination
	 */
	public String getDestination() {
		return destination;
	}

	/**
	 * The command destination : subsystem name or "*"
	 * 
	 * @param destination
	 */
	public void setDestination(String destination) {
		this.destination = destination;
	}

	/* locking and arbitrating */

	protected String key;

	/**
	 * Key used for lock and arbitration. If set, incoming commands must have
	 * the same key.
	 * 
	 * @return the key
	 */
	public String getKey() {
		return key;
	}

	/**
	 * Key used for lock and arbitration. If set, incoming commands must have
	 * the same key
	 * 
	 * @param key
	 */
	public void setKey(String key) {
		this.key = key;
	}

	/**
	 * is this command a writing command that has to be protected ?
	 */
	public boolean isWrite() {
		return true;
	}

	/* can this command wait for a single-threaded ownerSubsystem to be ready */
	protected boolean canWaitForReady = true;

	/**
	 * can this command wait for a single-threaded ownerSubsystem to be ready ?
	 * 
	 * @return a boolean
	 */
	public boolean canWaitForReady() {
		return canWaitForReady;
	}

	/**
	 * can this command wait for a single-threaded ownerSubsystem to be ready
	 * 
	 * @param canWaitForReady
	 */
	public void setCanWaitForReady(boolean canWaitForReady) {
		this.canWaitForReady = canWaitForReady;
	}

	protected boolean canRunInActiveMode = true;

	/**
	 * Can this command be executed by a subsystem which is in "active" mode ?
	 * 
	 * @return a boolean
	 */

	public boolean canRunInActiveMode() {
		return canRunInActiveMode;
	}

	public void setCanRunInActiveMode(boolean canRunInActiveMode) {
		this.canRunInActiveMode = canRunInActiveMode;
	}

	@Override
	public String toString() {
		return getClass().getName() + " from " + origin + " to " + destination;
	}

	/**
	 * Correlation id, propagated from command to command
	 */
	String correlId;

	public String getCorrelId() {
		return correlId;
	}

	/**
	 * Correlation id, propagated from command to command
	 */
	public void setCorrelId(String correlId) {
		this.correlId = correlId;
	}

}

==> org-lsst-ccs-buses-definition-1.0.9-sources.jar: org/lsst/ccs/bus/Command.java <==
package org.lsst.ccs.bus;

import org.lsst.ccs.utilities.logging.Logger;

/**
 * A command sent on the CCS bus
 * 
 * Will be executed by the destination subsystem.
 * 
 * 
 * @author Eric Aubourg
 * 
 */

public abstract class Command extends BusMessage implements CommandBusMessage {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1350212411027899551L;
	protected static Logger log = Logger.getLogger("lsst.ccs.bus.Command");

	public abstract Object execute(CommandExecutor s);

	@Override
	public String getMessageType() {
		return "lsst.command";
	}

	/* targeting */

	protected String destination = "*";

	/**
	 * The command destination : subsystem name or "*"
	 * 
	 * @return command destination
	 */
	public String getDestination() {
		return destination;
	}

	/**
	 * The command destination : subsystem name or "*"
	 * 
	 * @param destination
	 */
	public void setDestination(String destination) {
		this.destination = destination;
	}

	/* locking and arbitrating */

	protected String key;

	/**
	 * Key used for lock and arbitration. If set, incoming commands must have
	 * the same key.
	 * 
	 * @return the key
	 */
	public String getKey() {
		return key;
	}

	/**
	 * Key used for lock and arbitration. If set, incoming commands must have
	 * the same key
	 * 
	 * @param key
	 */
	public void setKey(String key) {
		this.key = key;
	}

	/**
	 * is this command a writing command that has to be protected ?
	 */
	public boolean isWrite() {
		return true;
	}

	/* can this command wait for a single-threaded ownerSubsystem to be ready */
	protected boolean canWaitForReady = true;

	/**
	 * can this command wait for a single-threaded ownerSubsystem to be ready ?
	 * 
	 * @return a boolean
	 */
	public boolean canWaitForReady() {
		return canWaitForReady;
	}

	/**
	 * can this command wait for a single-threaded ownerSubsystem to be ready
	 * 
	 * @param canWaitForReady
	 */
	public void setCanWaitForReady(boolean canWaitForReady) {
		this.canWaitForReady = canWaitForReady;
	}

	protected boolean canRunInActiveMode = true;

	/**
	 * Can this command be executed by a subsystem which is in "active" mode ?
	 * 
	 * @return a boolean
	 */

	public boolean canRunInActiveMode() {
		return canRunInActiveMode;
	}

	public void setCanRunInActiveMode(boolean canRunInActiveMode) {
		this.canRunInActiveMode = canRunInActiveMode;
	}

	@Override
	public String toString() {
		return getClass().getName() + " from " + origin + " to " + destination;
	}

	/**
	 * Correlation id, propagated from command to command
	 */
	String correlId;

	public String getCorrelId() {
		return correlId;
	}

	/**
	 * Correlation id, propagated from command to command
	 */
	public void setCorrelId(String correlId) {
		this.correlId = correlId;
	}

}
